/*
  Copyright (C) 1997,1998  Dimitrios P. Bouras

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   For author contact information, look in the README file.
*/

/* Callbacks */

void doLineInput(FL_OBJECT *, long);
void doTermOK(FL_OBJECT *, long);
void doTermAbort(FL_OBJECT *, long);

/* Forms and Objects */

typedef struct {
	FL_FORM *terminal;
	FL_OBJECT *lineBrowser;
	FL_OBJECT *termOK;
	FL_OBJECT *termAbort;
	void *vdata;
	long ldata;
} FD_terminal;

FD_terminal * create_form_terminal(void);

/* Other xispterm defines */

#define MAXBUF_INPUT 256	/* Input buffer size */

typedef struct {			/* the color structure */
	int r, g, b;
} color_t;

#define BGCOL_DEFAULT {79, 124, 156}	/* default form-background color */
#define BGCOL_STRING  "#4F7C9C"

